<?php

namespace Drupal\jsonapi_advanced_permissions\Permissions;

/**
 * Provides dynamic permissions for JSON:API collections.
 */
class JsonApiAdvancedPermissions
{

    /**
     * Returns dynamic permissions for JSON:API collections.
     *
     * @return array
     *   An array of permissions.
     */
    public function permissions()
    {
        $permissions = [];

        // JSON:API koleksiyonlarını dinamik olarak al.
        $routes = \Drupal::service('router.route_provider')->getAllRoutes();
        foreach ($routes as $route_name => $route) {
            $defaults = $route->getDefaults();
            if (!empty($defaults['_is_jsonapi']) && !empty($defaults['resource_type'])) {
                $resourceType = $defaults['resource_type'];
                $resourceTypeName = str_replace('--', ' ', $resourceType);
                $resourceTypeName = str_replace('_', ' ', $resourceTypeName);
                $configParts = \Drupal::config('jsonapi_advanced_permissions.settings')->get('permissions') ?? [];
                foreach ($configParts as $configPart) {
                    if ($route_name == 'jsonapi.' . $defaults['resource_type'] . '.' . $configPart) {
                        $methods = $route->getMethods();
                        $configPartName = explode('.', $configPart)[0];
                        $configPartName = str_replace('.', ' ', $configPartName);
                        $configName = ucwords($resourceTypeName . ' ' . $configPartName);
                        $resourceTypePermission = str_replace('.', '--', ($resourceType . '--' . $configPart));
                        $resourceTypePermission = str_replace('_', '-', $resourceTypePermission);

                        foreach ($methods as $method) {
                            $permissionName = str_replace('jsonapi.', '', $route_name);
                            $permissionName = str_replace('--', '__', $permissionName);
                            $permissionName = str_replace('.', ' ', $permissionName);
                            $methodName = strtolower($method);
                            $permissions["jsonapi_advanced_permissions $methodName on $permissionName"] = [
                                'title' => t('Access @method on @collection', ['@method' => $method, '@collection' => $configName]),
                            ];
                        }
                    }
                }
            }
        }
        return $permissions;
    }
}
